package com.hl.demo;

import android.Manifest;
import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.net.Uri;
import android.os.Bundle;
import android.provider.MediaStore;
import android.view.View;
import android.widget.TextView;

import com.hoolai.access.open.fastaccess.channel.FastSdk;
import com.hoolai.access.open.fastaccess.channel.request.ShareParams;
import com.hoolai.access.open.fastaccess.channel.request.ShareType;
import com.hoolai.access.open.fastaccess.interf.HLShareListener;

public class ShareActivity extends Activity {
    private TextView picPathTv, contentTv;
    private String picPath = "";//图片url
    private ShareParams params;//分享参数

    private static final int REQUEST_CODE = 100;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_share);
        picPathTv = findViewById(R.id.pic_path);
        contentTv = findViewById(R.id.main_tv);
        FastSdk.hlShareListener = new HLShareListener() {
            @Override
            public void onShareSuccess() {
                contentTv.setText("分享成功");
            }

            @Override
            public void onShareFailed(String s) {
                contentTv.setText("分享失败：" + s);
            }
        };
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (requestCode == REQUEST_CODE) {
            if (data != null) {
                Uri uri = data.getData();
                picPath = getImagePath(uri);
                picPathTv.setText(picPath);
            }
        }
    }

    public static void start(Context context) {
        Intent starter = new Intent(context, ShareActivity.class);
        context.startActivity(starter);
    }

    @Override
    public void onRequestPermissionsResult(int requestCode, String[] permissions, int[] grantResults) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults);
        if (requestCode == Manifest.permission.WRITE_EXTERNAL_STORAGE.hashCode()){
            if (grantResults[0] == PackageManager.PERMISSION_GRANTED) {
                params = new ShareParams();
                params.setTitle("分享标题");
                params.setContent("分享内容");
                params.setShareUrl("dongqiudi://share/circle/");
                params.setCallbackUrl("game://share/callback");
                params.setId("100");
                params.setPicPath(picPath);
                FastSdk.share(ShareType.DQD, ShareType.ChildType.DQD, params);
            }
        }
    }

    public void shareSelect(View v){
        Intent intent = new Intent(Intent.ACTION_PICK);
        intent.setDataAndType(MediaStore.Images.Media.EXTERNAL_CONTENT_URI, "image/*");
        startActivityForResult(intent, 100);
    }

    //懂球帝分享
    public void shareDQD(){
        if(FastSdk.checkPermission(this, Manifest.permission.WRITE_EXTERNAL_STORAGE)){
            params = new ShareParams();
            params.setTitle("分享标题");
            params.setContent("分享内容");
            params.setShareUrl("dongqiudi://share/circle/");
            params.setCallbackUrl("game://share/callback");
            params.setId("100");
            params.setPicPath(picPath);
            FastSdk.share(ShareType.DQD, ShareType.ChildType.DQD, params);
        }
    }

    //QQ分享（文字、图片）
    public void shareQQ(View v){
        ShareParams params = new ShareParams();
        params.setTitle("分享标题");
        params.setContent("分享内容");
        params.setPicPath(picPath);
        FastSdk.share(ShareType.QQ, ShareType.ChildType.QQ_IMG, params);
    }

    //微信分享（文字、图片）
    public void shareWX(View v){
        Bitmap bmp = BitmapFactory.decodeResource(this.getResources(), R.drawable.icon);
        ShareParams params = new ShareParams();
        params.setTitle("分享标题");
        params.setContent("分享内容");
        params.setShareUrl("分享链接");
        params.setPicPath("图片地址");
        params.setBmp(bmp);
        FastSdk.share(ShareType.WX, ShareType.ChildType.WX_CHAT, params);
    }

    //Facebook分享（链接、图片、视频）
    public void shareFacebook(View v){
        ShareParams params = new ShareParams();
        params.setTitle("分享标题");
        params.setContent("分享内容");
        params.setShareUrl("分享链接");
        params.setPicPath("图片/视频链接");
        FastSdk.share(ShareType.FACEBOOK, ShareType.ChildType.FACEBOOK_IMG, params);
    }

    //系统分享（文字、图片、文件）
    public void shareSystem(View v){
        ShareParams params = new ShareParams();
        params.setTitle("分享标题");
        params.setContent("分享内容");
        params.setShareUrl("分享链接");
        params.setPicPath("图片/视频链接");
        FastSdk.share(ShareType.SYSTEM, ShareType.ChildType.SYSTEM_IMG, params);
    }

    private String getImagePath(Uri uri) {
        if (uri != null) {
            String[] imgs = {
                    MediaStore.Images.Media._ID, MediaStore.Images.Media.DATA
            };
            Cursor cursor = getContentResolver().query(uri, imgs, null, null, null);
            try {
                if (cursor != null && cursor.moveToFirst()) {
                    return cursor.getString(1);
                }
            } finally {
                if (cursor != null){
                    cursor.close();
                }
            }
        }
        return null;
    }
}
